@@ -1,3 +1,5 @@
+#ifdef HAVE_NARRAY_H
+
 #include "narray.h"
 #include "gsl/gsl_vector.h"
 
@@ -15,3 +17,6 @@ gsl_vector* na_to_gv(VALUE na);
 gsl_vector_int* na_to_gv_int(VALUE na);
 gsl_matrix* na_to_gm(VALUE nna);
 gsl_matrix_int* na_to_gm_int(VALUE nna);
+extern VALUE cNVector, cNMatrix;
+
+#endif
